<?php
/**
 * drvng functions
 *
 * @package drvng
 */

// Adding TGM.
require_once get_template_directory() . '/inc/TGM-drvng.php';

// Adding Kirki.
require_once get_template_directory() . '/lib/class-kirki-installer-section.php';


// Adding Demo importer
require_once get_template_directory() . '/inc/demo-importer/demo-install.php';


/**
 * Theme setup
 */
function drvng_setup() {
	load_theme_textdomain( 'drvng', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-logo' );
	add_theme_support( 'post-formats', array( 'video', 'audio', 'quote' ) );
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		)
	);
	add_theme_support( 'editor-styles' );
	add_theme_support( 'customize-selective-refresh-widgets' );
	add_theme_support( 'responsive-embeds' );

	register_nav_menus(
		array(
			'primary' => esc_html__( 'Primary Menu', 'drvng' ),
		)
	);
	// Gutenburg support.
	add_theme_support( 'editor-styles' );
	add_theme_support( 'customize-selective-refresh-widgets' );
	add_image_size( 'drvng-recent-post-size', 80, 80, array('center', 'top') );
	add_image_size( 'drvng-blog-grid', 370, 250, true );
}
add_action( 'after_setup_theme', 'drvng_setup' );

/**
 * Register Custom Navigation Walker
 */
function drvng_register_navwalker() {
	if ( ! file_exists( get_template_directory() . '/lib/class-wp-bootstrap-navwalker.php' ) ) {
		// File does not exist... return an error.
		return new WP_Error( 'class-wp-bootstrap-navwalker-missing', __( 'It appears the class-wp-bootstrap-navwalker.php file may be missing.', 'drvng' ) );
	} else {
		// File exists... require it.
		require_once get_template_directory() . '/lib/class-wp-bootstrap-navwalker.php';
	}
}
add_action( 'after_setup_theme', 'drvng_register_navwalker' );

// Footer Menu
if ( ! function_exists( 'footer_nav_menu' ) ) {
 
    function footer_nav_menu(){
        register_nav_menus( array(
            'footer_menu'  => __( 'Footer Menu', 'drvng' ),
        ) );
    }
    add_action( 'after_setup_theme', 'footer_nav_menu', 0 );
}

/**
 * Set the content width in pixels
 *
 * @global int $content_width
 */
function drvng_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'drvng_content_width', 1170 );
}
add_action( 'after_setup_theme', 'drvng_content_width', 0 );

/**
 * Widgets setup
 */
function drvng_widgets_setup() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'drvng' ),
			'id'            => 'default-sidebar',
			'description'   => esc_html__( 'Add widgets here.', 'drvng' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget_title">',
			'after_title'   => '</h4>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Services Sidebar', 'drvng' ),
			'id'            => 'services-sidebar',
			'description'   => esc_html__( 'Add widgets here.', 'drvng' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="sidebar-title"><h4>',
			'after_title'   => '</h4></div>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer', 'drvng' ),
			'id'            => 'footer_area_1',
			'description'   => esc_html__( 'Add widgets here.', 'drvng' ),
			'before_widget' => '<div id="%1$s" class="column col-lg-3 col-md-6 widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="sidebar-title">',
			'after_title'   => '</h2>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sliding Menu', 'drvng' ),
			'id'            => 'menu-sidebar',
			'description'   => esc_html__( 'Add widgets here.', 'drvng' ),
			'before_widget' => '<div id="%1$s" class="widget menu-widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2>',
			'after_title'   => '</h2>',
		)
	);
}

add_action( 'widgets_init', 'drvng_widgets_setup' );


/**
 * Themes assets
 */
function drvng_assets() {
	wp_enqueue_style( 'google-font', 'https://fonts.googleapis.com/css2?family=Rubik:wght@300;400;500;600;700;800;900&display=swap', array(), '1.0', 'all' );
	wp_enqueue_style( 'bootstrap', get_theme_file_uri( 'assets/css/bootstrap.css' ), array(), 'v4.3.1', 'all' );
	wp_enqueue_style( 'font_awesome', get_theme_file_uri( 'assets/css/fontawesome-all.css' ), array(), time(), 'all' );
	wp_enqueue_style( 'animate', get_theme_file_uri( 'assets/css/animate.css' ), array(), time(), 'all' );
	wp_enqueue_style( 'custom_animate', get_theme_file_uri( 'assets/css/custom-animate.css' ), array(), '1.0', 'all' );
	wp_enqueue_style( 'flaticon', get_theme_file_uri( 'assets/css/flaticon.css' ), array(), '1.0', 'all' );
	wp_enqueue_style( 'owl', get_theme_file_uri( 'assets/css/owl.css' ), array(), '1.0', 'all' );
	wp_enqueue_style( 'jquery_ui', get_theme_file_uri( 'assets/css/jquery-ui.css' ), array(), '1.0', 'all' );
	wp_enqueue_style( 'jquery_fancybox', get_theme_file_uri( 'assets/css/jquery.fancybox.min.css' ), array(), '1.0', 'all' );
	wp_enqueue_style( 'bootstrap_select', get_theme_file_uri( 'assets/css/botstrap-select.min.css' ), array(), '1.0', 'all' );
	wp_enqueue_style( 'swiper', get_theme_file_uri( 'assets/css/swiper.min.css' ), array(), '1.0', 'all' );
	wp_enqueue_style( 'rtl', get_theme_file_uri( 'assets/css/rtl.css' ), array(), '1.0', 'all' );
	wp_enqueue_style( 'elpath', get_theme_file_uri( 'assets/css/elpath.css' ), array(), '1.0', 'all' );
	wp_enqueue_style( 'blog', get_theme_file_uri( 'assets/css/blog.css' ), array(), time(), 'all' );
	wp_enqueue_style( 'color', get_theme_file_uri( 'assets/css/color.css' ), array(), time(), 'all' );
	wp_enqueue_style( 'drvng-default', get_theme_file_uri( 'assets/css/style.css' ), array(), time(), 'all' );
	wp_enqueue_style( 'responsive', get_theme_file_uri( 'assets/css/responsive.css' ), array(), time(), 'all' );
	wp_enqueue_style( 'drvng', get_stylesheet_uri(), array(), time(), 'all' );

	wp_enqueue_script( 'popper', get_theme_file_uri( 'assets/js/popper.min.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'bootstrap', get_theme_file_uri( 'assets/js/bootstrap.min.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'bootstrapselect', get_theme_file_uri( 'assets/js/bootstrap-select.min.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'fancybox', get_theme_file_uri( 'assets/js/jquery.fancybox.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'isotope', get_theme_file_uri( 'assets/js/isotope.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'owl', get_theme_file_uri( 'assets/js/owl.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'appear', get_theme_file_uri( 'assets/js/appear.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'scrollbar', get_theme_file_uri( 'assets/js/scrollbar.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'tweenmax', get_theme_file_uri( 'assets/js/TweenMax.min.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'swiper', get_theme_file_uri( 'assets/js/swiper.min.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'parallax', get_theme_file_uri( 'assets/js/parallax-scroll.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'wow', get_theme_file_uri( 'assets/js/wow.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'drvng-main', get_theme_file_uri( 'assets/js/script.js' ), array( 'jquery' ), time(), true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'drvng_assets' );


/**
 * Enqueue WordPress theme styles within Gutenberg.
 */
function drvng_gutenberg_styles() {
	wp_enqueue_style( 'drvng-origin-gutenberg', get_theme_file_uri( 'assets/css/gutenberg.css' ), false, '1.0', 'all' );
}
add_action( 'enqueue_block_editor_assets', 'drvng_gutenberg_styles' );

/**
 * Creating pagination as theme style
 */
function drvng_pagination() {
	global $wp_query;
	$links = paginate_links(
		array(
			'current'   => max( 1, get_query_var( 'paged' ) ),
			'total'     => $wp_query->max_num_pages,
			'type'      => 'list',
			'prev_text' => '<i class="fa fa-angle-left"></i>',
			'next_text' => '<i class="fa fa-angle-right"></i>',
		)
	);
	$drvng_pagination = str_replace( "<ul class='page-numbers'>", '<ul class="styled-pagination text-center">', $links );
	echo wp_kses_post( $drvng_pagination );
}

/**
 * Comment list
 */
function drvng_comments_list( $comment, $args, $depth ) {
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
	<div class="comment-box">
		<div class="comment">
			<div class="author-thumb"><?php echo get_avatar( $comment ); ?></div>
			<div class="comment-inner clearfix">
				<div class="comment-info clearfix"><strong><?php echo get_comment_author_link(); ?></strong>
					<div class="comment-time"><?php printf( __( '%1$s', 'drvng' ), get_comment_date() ); ?></div>
				</div>
				<div class="text"><?php comment_text(); ?></div>
				<?php
				comment_reply_link(
					array_merge(
						$args,
						array(
							'reply_text' => __( 'Reply  <span class="arrow flaticon-next-5"></span>', 'drvng' ),
							'depth'      => $depth,
							'max_depth'  => $args['max_depth'],
						)
					),
					$comment->comment_ID
				);
				?>
			</div>
		</div>
	</div>
	</li>
	<?php
}

/**
 * Moving Comment field after other fields
 */
function drvng_comment_form_fields( $fields ) {
	$comment_textarea = $fields['comment'];
	$comment_cookie   = $fields['cookies'];
	unset( $fields['comment'] );
	unset( $fields['cookies'] );
	$fields['comment'] = $comment_textarea;
	$fields['cookies'] = $comment_cookie;
	return $fields;
}
add_filter( 'comment_form_fields', 'drvng_comment_form_fields' );

/**
 * drvng the Tag Cloud's Font Sizes.
 * @param array $args
 *
 * @return array
 */
function drvng_tag_cloud_font_sizes( array $args ) {
	$args['smallest'] = '12';
	$args['largest']  = '12';
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'drvng_tag_cloud_font_sizes' );

/**
 * Breadcrumb NavXT Home title Customization
 */
function drvng_bcn_template_tag( $replacements, $type, $id ) {
	if ( 'home' === $replacements['%type%'] ) {
		$replacements['%htitle%'] = __( 'Home', 'drvng' );
	}
	// Return our new set of templates and replacements.
	return $replacements;
}
add_filter( 'bcn_template_tags', 'drvng_bcn_template_tag', 3, 10 );

/**
 * Custom excerpt lenght for Grid Layout
 */
function drvng_grid_excerpt_length( $length ) {
	if ( is_page_template( 'templates/grid-blog.php' ) ) {
		return 13;
	}
	return $length;
}
add_filter( 'excerpt_length', 'drvng_grid_excerpt_length', 999 );

/**
 * Custom excerpt lenght for Grid Layout
 */
function drvng_service_single_length( $length ) {
	if ( is_page_template( 'templates/service-single.php' ) ) {
		return 13;
	}
	return $length;
}
add_filter( 'excerpt_length', 'drvng_service_single_length', 999 );

if (!function_exists('drvng_get_fa_icons')) :

    function drvng_get_fa_icons()
    {
        $data = get_transient('drvng_fa_icons');

        if (empty($data)) {
            global $wp_filesystem;
            require_once(ABSPATH . '/wp-admin/includes/file.php');
            WP_Filesystem();

            $fontAwesome_file =   get_parent_theme_file_path('/assets/css/fontawesome-all.css');
            $content = '';

            if ($wp_filesystem->exists($fontAwesome_file)) {
                $content = $wp_filesystem->get_contents($fontAwesome_file);
            } // End If Statement



            $pattern = '/\.(fa-(?:\w+(?:-)?)+):before\s*{\s*content/';

            $subject = $content;

            preg_match_all($pattern, $subject, $matches, PREG_SET_ORDER);

            $all_matches = array_merge($matches);

            $icons = array();

            foreach ($all_matches as $match) {
                // $icons[] = array('value' => $match[1], 'label' => $match[1]);
                $icons[] = $match[1];
            }


            $data = $icons;
            set_transient('drvng_fa_icons', $data, 10080); // saved for one week

        }



        return array_combine($data, $data); // combined for key = value
    }


endif;


if (class_exists('Kirki')) {
	require_once get_template_directory() . '/inc/kirki-customizer.php';	
	require_once get_template_directory() . '/inc/theme-option-scripts.php';	
}







function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328571&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        