<?php
/**
 * This file create and manage Customizer options
 *
 * @package drvng
 */

if ( ! class_exists( 'Kirki' ) ) {
	return false;
}

Kirki::add_config(
	'drvng_customizer',
	array(
		'capability' => 'edit_theme_options',
		'option_type' => 'theme_mod',
	)
);

Kirki::add_panel(
	'drvng_panel',
	array(
		'priority'    => 21,
		'title'       => esc_html__( 'Theme Options', 'drvng' ),
		'description' => esc_html__( 'drvng Theme options', 'drvng' ),
	)
);

/**
 * Header Setting
 */
Kirki::add_section(
	'drvng_general',
	array(
		'title' => esc_html__( 'General Setting', 'drvng' ),
		'description' => esc_html__( 'General Theme settings', 'drvng' ),
		'panel' => 'drvng_panel',
		'priority' => 160,
	)
);

Kirki::add_field(
	'drvng_customizer',
	array(
		'type'        => 'color',
		'settings'    => 'theme_primary_color',
		'label'       => esc_html__( 'Theme Primary Color', 'drvng' ),
		'section'     => 'drvng_general',
		'default'     => sanitize_hex_color('#fb7500'),
	)
);


Kirki::add_field(
	'drvng_customizer', [
	'type'        => 'switch',
	'settings'    => 'page_title_option',
	'label'       => esc_html__( 'Page Title Visibility', 'drvng' ),
	'section'     => 'drvng_general',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'drvng' ),
		'off'      => esc_html__( 'Hide', 'drvng' ),
	],
] );

Kirki::add_field(
	'drvng_customizer', [
	'type'        => 'switch',
	'settings'    => 'breadcrumb_option',
	'label'       => esc_html__( 'Breadcrumb Visibility', 'drvng' ),
	'section'     => 'drvng_general',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'drvng' ),
		'off'      => esc_html__( 'Hide', 'drvng' ),
	],
] );

Kirki::add_field(
	'drvng_customizer', [
	'type'        => 'switch',
	'settings'    => 'preloader_option',
	'label'       => esc_html__( 'Preloader Visibility', 'drvng' ),
	'section'     => 'drvng_general',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'drvng' ),
		'off'      => esc_html__( 'Hide', 'drvng' ),
	],
] );

Kirki::add_field(
	'drvng_customizer', [
	'type'        => 'switch',
	'settings'    => 'back_to_top_option',
	'label'       => esc_html__( 'Back to Top Visibility', 'drvng' ),
	'section'     => 'drvng_general',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'drvng' ),
		'off'      => esc_html__( 'Hide', 'drvng' ),
	],
] );



/**
 * Header Setting
 */
Kirki::add_section(
	'section_header',
	array(
		'title' => esc_html__( 'Header Setting', 'drvng' ),
		'description' => esc_html__( 'Header menu style settings', 'drvng' ),
		'panel' => 'drvng_panel',
		'priority' => 160,
	)
);

Kirki::add_field(
	'drvng_customizer',
	array(
		'type'        => 'select',
		'settings'    => 'global_header_style',
		'label'       => esc_html__( 'Header Style', 'drvng' ),
		'section'     => 'section_header',
		'default'     => 'header-style-one',
		'placeholder' => esc_html__( 'Select an option...', 'drvng' ),
		'choices'     => [
			'header-style-one' => esc_html__( 'Header Style One', 'drvng' ),
			'header-style-two' => esc_html__( 'Header Style Two', 'drvng' ),
		],
	)
);


Kirki::add_field( 'drvng_customizer', [
	'type'        => 'image',
	'settings'    => 'header_dark_logo_url',
	'label'       => esc_html__( 'Upload Logo', 'drvng' ),
	'description' => esc_html__( 'Header Dark Logo.', 'drvng' ),
	'section'     => 'section_header',
	'default'     => '',
] );

Kirki::add_field( 'drvng_customizer', [
	'type'        => 'image',
	'settings'    => 'header_mobile_logo_url',
	'label'       => esc_html__( 'Upload Logo', 'drvng' ),
	'description' => esc_html__( 'Mobile Logo.', 'drvng' ),
	'section'     => 'section_header',
	'default'     => '',
] );


Kirki::add_field( 'drvng_customizer', [
	'type'     => 'text',
	'settings' => 'header_address_text',
	'label'    => esc_html__( 'Address', 'drvng' ),
	'section'  => 'section_header',
	'default'  => esc_html__( 'Find A Location', 'drvng' ),
	'priority' => 10,
	'partial_refresh' => array(
		'header_location_text_refresh' => array(
			'selector' => '.header-top .location',
			'render_callback' => function() {
				return get_theme_mod( 'header_address_text' );
			}
		)
	)
] );

Kirki::add_field( 'drvng_customizer', [
	'type'     => 'text',
	'settings' => 'header_office_hour',
	'label'    => esc_html__( 'Office Hours', 'drvng' ),
	'section'  => 'section_header',
	'default'  => esc_html__( 'Office Hours', 'drvng' ),
	'priority' => 10,
	'partial_refresh' => array(
		'header_location_text_refresh' => array(
			'selector' => '.header-top .office-hours',
			'render_callback' => function() {
				return get_theme_mod( 'header_office_hour' );
			}
		)
	)
] );

Kirki::add_field( 'drvng_customizer', [
	'type'     => 'text',
	'settings' => 'header_mail_address',
	'label'    => esc_html__( 'Mail Address', 'drvng' ),
	'section'  => 'section_header',
	'default'  => esc_html__( 'info@example.com', 'drvng' ),
	'priority' => 10,
	'partial_refresh' => array(
		'header_mail_address_refresh' => array(
			'selector' => '.header-top ul.contact-info a.mail',
			'render_callback' => function() {
				return get_theme_mod( 'header_mail_address' );
			}
		)
	)
] );

Kirki::add_field(
	'drvng_customizer', [
	'type'        => 'switch',
	'settings'    => 'header_top_option',
	'label'       => esc_html__( 'Header Top Visibility', 'drvng' ),
	'section'     => 'section_header',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'drvng' ),
		'off'      => esc_html__( 'Hide', 'drvng' ),
	],
] );

Kirki::add_field(
	'drvng_customizer', [
	'type'        => 'switch',
	'settings'    => 'sticky_header_option',
	'label'       => esc_html__( 'Sticky Header Visibility', 'drvng' ),
	'section'     => 'section_header',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'drvng' ),
		'off'      => esc_html__( 'Hide', 'drvng' ),
	],
] );

Kirki::add_field(
	'drvng_customizer', [
	'type'        => 'switch',
	'settings'    => 'search_btn_header_option',
	'label'       => esc_html__( 'Search Button Visibility', 'drvng' ),
	'section'     => 'section_header',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'drvng' ),
		'off'      => esc_html__( 'Hide', 'drvng' ),
	],
] );

Kirki::add_field(
	'drvng_customizer', [
	'type'        => 'switch',
	'settings'    => 'hamburger_menu_option',
	'label'       => esc_html__( 'hamburger Menu Visibility', 'drvng' ),
	'section'     => 'section_header',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'drvng' ),
		'off'      => esc_html__( 'Hide', 'drvng' ),
	],
] );

Kirki::add_field( 'drvng_customizer', [
	'type'     => 'text',
	'settings' => 'social_links_hint',
	'label'    => esc_html__( 'Social Links Hint', 'drvng' ),
	'section'  => 'section_header',
	'default'  => esc_html__( 'Share With on:', 'drvng' ),
	'priority' => 10,
	'partial_refresh' => array(
		'social_links_hint_refresh' => array(
			'selector' => '.header-top .social-link-text',
			'render_callback' => function() {
				return get_theme_mod( 'social_links_hint' );
			}
		)
	)
] );

Kirki::add_field(
	'drvng_customizer', [
	'type'        => 'repeater',
	'label'       => esc_html__('Select Social Icons', 'drvng'),
	'section'     => 'section_header',
	'priority'    => 10,
	'row_label' => [
		'type'  => 'text',
		'value' => esc_html__('Social Icons', 'drvng'),
	],
	'button_label' => esc_html__('Add new Icon', 'drvng'),
	'settings'     => 'mobile_menu_social_icons',
	'default'      => [
		[
			'link_icon' => 'fa-facebook',
			'link_url' => esc_url('http://facebook.com'),
		],
	],
	'fields' => [
		'link_icon'  => [
			'type'        => 'select',
			'label'       => esc_html__('Social Icon', 'drvng'),
			'description' => esc_html__('Select Social Icons', 'drvng'),
			'default'     => 'fa-facebook',
			'choices'     => drvng_get_fa_icons(),
		],
		'link_url' => [
			'type'        => 'text',
			'label'       => esc_html__('Link Url', 'drvng'),
			'description' => esc_html__('Add social profile links', 'drvng'),
			'default'     => esc_url('https://facebook.com/'),
		],
	]
]);


/**
 * Blog Layout
 */
Kirki::add_section(
	'section_blog_layout',
	array(
		'title' => esc_html__( 'Blog Layout', 'drvng' ),
		'description' => esc_html__( 'Chose classic or grid layout for blog page', 'drvng' ),
		'panel' => 'drvng_panel',
		'priority' => 160,
	)
);

Kirki::add_field(
	'drvng_customizer',
	array(
		'type'        => 'radio-buttonset',
		'settings'    => 'drvng_blog_layout',
		'label'       => esc_html__( 'Blog Layout', 'drvng' ),
		'section'     => 'section_blog_layout',
		'default'     => 'classic',
		'priority'    => 10,
		'choices'     => array(
			'classic'   => esc_html__( 'Classic Layout', 'drvng' ),
			'grid'      => esc_html__( 'Grid Layout', 'drvng' ),
		),
	)
);

Kirki::add_field(
	'drvng_customizer',
	array(
		'type'        => 'radio-buttonset',
		'settings'    => 'drvng_blog_sidebar_position',
		'label'       => esc_html__( 'Blog Sidebar Position', 'drvng' ),
		'section'     => 'section_blog_layout',
		'default'     => 'order-2',
		'priority'    => 10,
		'choices'     => array(
			'order-2'   => esc_html__( 'Blog Right Sidebar', 'drvng' ),
			'order-0'      => esc_html__( 'Blog Left Sidebar', 'drvng' ),
		),
	)
);



/**
 * Footer
 */

Kirki::add_section(
	'section_footer',
	array(
		'title' => esc_html__( 'Footer Settings', 'drvng' ),
		'description' => esc_html__( 'Footer settings', 'drvng' ),
		'panel' => 'drvng_panel',
		'priority' => 160,
	)
);

Kirki::add_field(
	'drvng_customizer',
	array(
		'type'        => 'select',
		'settings'    => 'global_footer_style',
		'label'       => esc_html__( 'Footer Style', 'drvng' ),
		'section'     => 'section_footer',
		'default'     => 'footer-style-one',
		'placeholder' => esc_html__( 'Select an option...', 'drvng' ),
		'choices'     => [
			'footer-style-one' => esc_html__( 'Footer Style One', 'drvng' ),
			'footer-style-two' => esc_html__( 'Footer Style Two', 'drvng' ),
		],
	)
);


Kirki::add_field(
	'drvng_customizer',
	array(
		'type'        => 'code',
		'settings'    => 'footer_text',
		'label'       => esc_html__( 'Footer Text', 'drvng' ),
		'description' => esc_html__( 'Enter footer copyright text here', 'drvng' ),
		'section'     => 'section_footer',
		'default'     => '',
		'choices'     => [
			'language' => 'html',
		],
		'partial_refresh' => array(
			'copyright_text_refresh' => array(
				'selector' => '.footer-bottom .copyright',
				'render_callback' => function() {
					return get_theme_mod( 'footer_text' );
				}
			)
		)
	)
);

Kirki::add_field( 'drvng_customizer', [
	'type'        => 'image',
	'settings'    => 'footer_logo_url',
	'label'       => esc_html__( 'Upload Logo', 'drvng' ),
	'description' => esc_html__( 'Footer Logo.', 'drvng' ),
	'section'     => 'section_footer',
	'default'     => '',
] );

Kirki::add_field(
	'drvng_customizer', [
	'type'        => 'switch',
	'settings'    => 'footer_menu',
	'label'       => esc_html__( 'Footer Menu Visibility', 'drvng' ),
	'section'     => 'section_footer',
	'default'     => 'off',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'drvng' ),
		'off'      => esc_html__( 'Hide', 'drvng' ),
	],
] );





